
Sageチュートリアルへようこそ
================================

Sageは，代数学，幾何学，数論，暗号理論，数値解析，および関連諸分野の研究と教育を支援する，フリーなオープンソース数学ソフトウェアである．
Sageの開発モデルとテクノロジーに共通する著しい特徴は，公開，共有，協調と協働の原則の徹底的な遵守である．
我々の目的は言わば実用車の制作であって，車輪を再発明することではない．
総合目標としているのは，Maple，Mathematica，Magma，MATLABに代りうるフリーかつオープンソース化された実用システムの開発である．

Sageがどんなものか，短時間で知りたければ，まずこのチュートリアルを読んでみていただきたい．
HTML版とPDF版のどちらを読んでもいいし，Sageノートブックを経由することもできる(チュートリアル内容を対話的に実行するには，ノートブックで ``Help`` ，  続けて ``Tutorial`` をクリックする)．

この文章の著作権は `Creative Commons Attribution-Share Alike 3.0 License`__ 
に準ずる．

__ http://creativecommons.org/licenses/by-sa/3.0/

.. toctree::
   :maxdepth: 2

   introduction
   tour
   interactive_shell
   interfaces
   latex
   programming
   sagetex
   afterword
   appendix
   bibliography

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
